agentle.agents.exceptions.skip\_tool\_call\_error
=================================================

.. automodule:: agentle.agents.exceptions.skip_tool_call_error

   
   .. rubric:: Exceptions

   .. autosummary::
   
      SkipToolCallError
   